package com.bonus.canteen.core.health.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.health.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.health.domain.HealthPersonMedicalReportDetail;
import com.bonus.canteen.core.health.service.IHealthPersonMedicalReportDetailService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 人员体检报告项目明细Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "人员体检报告项目明细接口")
@RestController
@RequestMapping("/health_person_medical_report_detail")
public class HealthPersonMedicalReportDetailController extends BaseController {
    @Autowired
    private IHealthPersonMedicalReportDetailService healthPersonMedicalReportDetailService;

    /**
     * 查询人员体检报告项目明细列表
     */
    @ApiOperation(value = "查询人员体检报告项目明细列表")
    //@RequiresPermissions("health:detail:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthPersonMedicalReportDetail healthPersonMedicalReportDetail) {
        startPage();
        List<HealthPersonMedicalReportDetail> list = healthPersonMedicalReportDetailService.selectHealthPersonMedicalReportDetailList(healthPersonMedicalReportDetail);
        return getDataTable(list);
    }

    /**
     * 导出人员体检报告项目明细列表
     */
    @ApiOperation(value = "导出人员体检报告项目明细列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:detail:export")
    @SysLog(title = "人员体检报告项目明细", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出人员体检报告项目明细")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthPersonMedicalReportDetail healthPersonMedicalReportDetail) {
        List<HealthPersonMedicalReportDetail> list = healthPersonMedicalReportDetailService.selectHealthPersonMedicalReportDetailList(healthPersonMedicalReportDetail);
        ExcelUtil<HealthPersonMedicalReportDetail> util = new ExcelUtil<HealthPersonMedicalReportDetail>(HealthPersonMedicalReportDetail.class);
        util.exportExcel(response, list, "人员体检报告项目明细数据");
    }

    /**
     * 获取人员体检报告项目明细详细信息
     */
    @ApiOperation(value = "获取人员体检报告项目明细详细信息")
    //@RequiresPermissions("health:detail:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(healthPersonMedicalReportDetailService.selectHealthPersonMedicalReportDetailById(id));
    }

    /**
     * 新增人员体检报告项目明细
     */
    @ApiOperation(value = "新增人员体检报告项目明细")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:detail:add")
    @SysLog(title = "人员体检报告项目明细", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增人员体检报告项目明细")
    @PostMapping
    public AjaxResult add(@RequestBody HealthPersonMedicalReportDetail healthPersonMedicalReportDetail) {
        try {
            return toAjax(healthPersonMedicalReportDetailService.insertHealthPersonMedicalReportDetail(healthPersonMedicalReportDetail));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改人员体检报告项目明细
     */
    @ApiOperation(value = "修改人员体检报告项目明细")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:detail:edit")
    @SysLog(title = "人员体检报告项目明细", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改人员体检报告项目明细")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HealthPersonMedicalReportDetail healthPersonMedicalReportDetail) {
        try {
            return toAjax(healthPersonMedicalReportDetailService.updateHealthPersonMedicalReportDetail(healthPersonMedicalReportDetail));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除人员体检报告项目明细
     */
    @ApiOperation(value = "删除人员体检报告项目明细")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:detail:remove")
    @SysLog(title = "人员体检报告项目明细", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除人员体检报告项目明细")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(healthPersonMedicalReportDetailService.deleteHealthPersonMedicalReportDetailByIds(ids));
    }
}
